"""
build_boundary script creates a sts file and csv files.
The sts files is necessary for run_perth.py 
The csv files are timeseries of the sts file determining the wave input

This script is determined by an inidividual event generated through
the Hazard map, refer to David Burbidge for details of inidivdual events
"""
import os
from os import sep
import project

from anuga.utilities.numerical_tools import ensure_numeric
from Scientific.IO.NetCDF import NetCDFFile
from Numeric import asarray,transpose,sqrt,argmax,argmin,arange,Float,\
    compress,zeros,fabs,allclose,ones
from anuga.utilities.polygon import inside_polygon,read_polygon
from time import localtime, strftime, gmtime
from anuga.shallow_water.data_manager import urs2sts,create_sts_boundary

try:
    from pylab import plot,show,xlabel,ylabel,legend,title,savefig,hold
except:
    print 'Cannot import pylab plotting will not work. Csv files are still created'

#--------------------------------------------------------------------------
# Create sts boundary from mux2files 
#--------------------------------------------------------------------------

dir=os.path.join(project.muxhome,'mux')

# Refer to event_027255.list in home+state+sep+event08 for event details
# taken from David's event list for 27255
urs_filenames = [
    os.path.join(dir,'Java-0017-z.grd'),  
    os.path.join(dir,'Java-0018-z.grd'),
    os.path.join(dir,'Java-0019-z.grd'),
    os.path.join(dir,'Java-0022-z.grd'),  
    os.path.join(dir,'Java-0023-z.grd'),  
    os.path.join(dir,'Java-0024-z.grd'),  
    os.path.join(dir,'Java-0027-z.grd'),  
    os.path.join(dir,'Java-0028-z.grd'),  
    os.path.join(dir,'Java-0031-z.grd'),  
    os.path.join(dir,'Java-0032-z.grd')]  
 
print 'number of sources', len(urs_filenames)

if len(urs_filnames) = 10 #change per event

    weight_factor = 30.84050 #change per event
    weights=weight_factor*ones(len(urs_filenames),Float)

    scenario_name=project.scenario_name
    order_filename=os.path.join(project.order_filename_dir)

    print 'reading', order_filename
    # Create ordered sts file
    print 'creating sts file'

    urs2sts(urs_filenames,
            basename_out=os.path.join(project.boundaries_dir_event,scenario_name),
            ordering_filename=order_filename,
            weights=weights,
            mean_stage=project.tide,
            verbose=True)
else print 'number of sources do not match event.list'

#------------------------------------------------------------------------------
# Get gauges (timeseries of index points)
#------------------------------------------------------------------------------
def get_sts_gauge_data(filename,verbose=False):
    from Numeric import asarray,transpose,sqrt,argmax,argmin,arange,Float,\
        compress,zeros,fabs,take
    fid = NetCDFFile(filename+'.sts', 'r')    #Open existing file for read
    permutation = fid.variables['permutation'][:]
    x = fid.variables['x'][:]+fid.xllcorner   #x-coordinates of vertices
    y = fid.variables['y'][:]+fid.yllcorner   #y-coordinates of vertices
    points=transpose(asarray([x.tolist(),y.tolist()]))
    time=fid.variables['time'][:]+fid.starttime
    elevation=fid.variables['elevation'][:]
       
    basename='sts_gauge'
    quantity_names=['stage','xmomentum','ymomentum']
    quantities = {}
    for i, name in enumerate(quantity_names):
        quantities[name] = fid.variables[name][:]

#------------------------------------------------------------------------------
# Get Maxium wave height throughout timeseries at each index point
#------------------------------------------------------------------------------

    maxname = 'max_sts_stage.csv'
    fid_max = open(project.boundaries_dir_event+sep+maxname,'w')
    s = 'index, x, y, max_stage \n'
    fid_max.write(s)    
    for j in range(len(x)):
        index= permutation[j]
        stage = quantities['stage'][:,j]
        xmomentum = quantities['xmomentum'][:,j]
        ymomentum = quantities['ymomentum'][:,j]

        s = '%d, %.6f, %.6f, %.6f\n' %(index, x[j], y[j], max(stage))
        fid_max.write(s)
        
        fid_sts = open(project.boundaries_dir_event+sep+basename+'_'+ str(index)+'.csv', 'w')
        s = 'time, stage, xmomentum, ymomentum \n'
        fid_sts.write(s)
        
        for k in range(len(time)-1):
            s = '%.6f, %.6f, %.6f, %.6f\n' %(time[k], stage[k], xmomentum[k], ymomentum[k])
            fid_sts.write(s)

        fid_sts.close()      

    fid.close()
        
    return quantities,elevation,time

quantities,elevation,time=get_sts_gauge_data(os.path.join(project.boundaries_dir_event,project.scenario_name),verbose=False)

print len(elevation), len(quantities['stage'][0,:])

